package com.kdm.erraiexample.config;

import static java.lang.String.format;

import javax.ws.rs.core.MediaType;
import javax.ws.rs.core.Response;
import javax.ws.rs.core.Response.Status;
import javax.ws.rs.ext.ExceptionMapper;
import javax.ws.rs.ext.Provider;

import org.apache.log4j.Logger;

/**
 * Add a generic exception handler that returns the exception message in the body in
 * a JSON payload instead of letting the default container behaviour takeover which
 * spews the full stacktrace out to the client in html format.
 */
@Provider
public class JaxRSExceptionMapper implements ExceptionMapper<Exception>
{
  private static final Logger log = Logger.getLogger(JaxRSExceptionMapper.class);
  private static final Status ERROR_STATUS = Status.INTERNAL_SERVER_ERROR;
  
  @Override
  public Response toResponse(Exception exception)
  {
    log.error(
        format("Returning error status (%d) to client: %s", ERROR_STATUS.getStatusCode(), exception.getMessage()), exception);
    
    return Response.status(ERROR_STATUS)
        .entity(exception.getMessage())
        .type(MediaType.APPLICATION_JSON_TYPE)
        .build();
  }
}
